==> haskell-tamarin-prover-sapic-1.8.0-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-sapic
version:              1.8.0
visibility:           public
id:                   tamarin-prover-sapic-1.8.0-HRNsFea8UJSCQanX98Xadm
key:                  tamarin-prover-sapic-1.8.0-HRNsFea8UJSCQanX98Xadm
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  65a18acb88dade69497c263cc7c164c7
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.8.0-HRNsFea8UJSCQanX98Xadm
depends:
    aeson-2.1.2.1-Explt7i9hRWCBVvHGUB5A2
    aeson-pretty-0.8.10-KU0CQnpr2i02e3vPodt5oi base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-1on6OJsGJpvA7loLHZHEq2 mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-FHqmWeL515h1ZDkEwV0YZX
    tamarin-prover-term-1.8.0-BsitReAwJ618Qnxmbb86D2
    tamarin-prover-theory-1.8.0-2ENEydIYPOB9hgK1CIvDCC
    tamarin-prover-utils-1.8.0-KP3I2gl6oan1gwKHWe6y6x text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-E9XLtnRxE39Lc36BhbYiEq

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-sapic-1.8.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-sapic
version:              1.8.0
visibility:           public
id:                   tamarin-prover-sapic-1.8.0-64oe1aTYm2uHgYz8f6U3Ra
key:                  tamarin-prover-sapic-1.8.0-64oe1aTYm2uHgYz8f6U3Ra
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  ddadc9a6a11715d57c167dff69803ddc
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.8.0-64oe1aTYm2uHgYz8f6U3Ra
depends:
    aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK
    aeson-pretty-0.8.10-1dlwPC4Gr0U23GIUJQ9AUw base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-FImK52swWA5JqZ1RvP2cAM mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-DycKuNeB2NrH0Uhgd9RWtv
    tamarin-prover-term-1.8.0-1kHA1dYF6KV2sqg5lPgSMF
    tamarin-prover-theory-1.8.0-Ex9mMXqMS2G8lLE1GqGIKV
    tamarin-prover-utils-1.8.0-BnKf77rEvthBPhzkGLSC3O text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-11xJxnG7KzmIv2px8kQrrx

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
